==> img0ch-2.1.9.zip: img0ch/_template/zeromin2/menu.cs <==
<div id="header">
  <div class="left">
    <p><a href="<?cs var:html_escape(ZerominScript) ?>">Zeromin</a></p>
  </div>
  <div class="subheader">
    <a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load&amp;item=<?cs var:html_escape(Item) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">掲示板</a> |
    <a href="<?cs var:html_escape(ZerominScript) ?>?class=user&amp;method=load&amp;item=<?cs var:html_escape(Item) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">ユーザー</a> |
    <a href="<?cs var:html_escape(ZerominScript) ?>?class=cap&amp;method=load&amp;item=<?cs var:html_escape(Item) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">キャップ</a> |
    <a href="<?cs var:html_escape(ZerominScript) ?>?class=banner&amp;method=load_main&amp;item=<?cs var:html_escape(Item) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">バナー</a> |
    <a href="<?cs var:html_escape(ZerominScript) ?>?class=filter&amp;method=load_ip&amp;item=<?cs var:html_escape(Item) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">アクセス制限</a> |
    <a href="<?cs var:html_escape(ZerominScript) ?>?class=plugin&amp;method=load&amp;item=<?cs var:html_escape(Item) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">プラグイン</a> |
    <a href="<?cs var:html_escape(ZerominScript) ?>?class=system&amp;method=load&amp;item=<?cs var:html_escape(Item) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">システム</a> |
    <a href="<?cs var:html_escape(ZerominScript) ?>?class=system&amp;method=logout&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">ログオフ</a>
  </div>
</div>

==> img0ch-3.0.1.zip: img0ch/_template/zeromin2/menu.cs <==
<div id="header">
  <div class="left">
    <p><a href="<?cs var:html_escape(ZerominScript) ?>">Zeromin</a></p>
  </div>
  <div class="subheader">
    <a href="<?cs var:html_escape(ZerominScript) ?>?class=message&amp;method=load&amp;item=<?cs var:html_escape(Item) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">通知</a> |
    <a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load&amp;item=<?cs var:html_escape(Item) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">掲示板</a> |
    <a href="<?cs var:html_escape(ZerominScript) ?>?class=user&amp;method=load&amp;item=<?cs var:html_escape(Item) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">ユーザー</a> |
    <a href="<?cs var:html_escape(ZerominScript) ?>?class=cap&amp;method=load&amp;item=<?cs var:html_escape(Item) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">キャップ</a> |
    <a href="<?cs var:html_escape(ZerominScript) ?>?class=banner&amp;method=load_main&amp;item=<?cs var:html_escape(Item) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">バナー</a> |
    <a href="<?cs var:html_escape(ZerominScript) ?>?class=filter&amp;method=load_ip&amp;item=<?cs var:html_escape(Item) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">アクセス制限</a> |
    <a href="<?cs var:html_escape(ZerominScript) ?>?class=plugin&amp;method=load&amp;item=<?cs var:html_escape(Item) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">プラグイン</a> |
    <a href="<?cs var:html_escape(ZerominScript) ?>?class=system&amp;method=load&amp;item=<?cs var:html_escape(Item) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">システム</a> |
    <a href="<?cs var:html_escape(ZerominScript) ?>?class=system&amp;method=logout&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">ログオフ</a>
  </div>
</div>
